//
//  TouchScene.cpp
//  layer_touch_single
//
//  Created by Reza Ghobadinic on 2019-10-27.
//

#include "TouchScene.h"
#include <iostream>

USING_NS_CC;
using namespace std;

Scene* TouchScene::createScene()
{
    auto scene = Scene::create();
    auto layer = TouchScene::create();
    
    scene->addChild(layer);
    
    return scene;
}

bool TouchScene::init()
{
    auto listener = EventListenerTouchAllAtOnce::create(); // Create a single touch listener
    
    listener->onTouchesBegan = [this] (const std::vector<Touch*>& touches, Event *event)
    {
        for(auto& touch : touches)
        {
            auto sprite = Sprite::create("circle.png");
            sprite->setPosition(touch->getLocation());
            this->addChild(sprite, 0, touch->getID());
        }
        return true;
    };
    
    listener->onTouchesMoved = [this] (const std::vector<Touch*>& touches, Event *event)
    {
        for(auto& touch : touches)
        {
            auto sprite = this->getChildByTag(touch->getID());
            sprite->setPosition(touch->getLocation());
        }
    };
    
    listener->onTouchesEnded = [this] (const std::vector<Touch*>& touches, Event *event)
    {
        for(auto& touch : touches)
            this->removeChildByTag(touch->getID());
    };
    
    listener->onTouchesCancelled = [this] (const std::vector<Touch*>& touches, Event *event)
    {
        for(auto& touch : touches)
            this->removeChildByTag(touch->getID());
    };
    
    _eventDispatcher->addEventListenerWithSceneGraphPriority(listener, this);
    
    return true;
}
